# 这是README
君禹科技的python库
## 字体
*这是斜体*
_这是斜体_
**这是粗体**
__这是粗体__
***这是粗斜体***
___这是粗斜体___

## 引用
>这是一个引用
>> 这是一个引用的引用

## 链接
[百度](https://www.baidu.com)
或者
[百度]
<https://www.baidu.com>

## 图片

<img alt="图片描述" height="300" src="C:\Users\Administrator\Pictures\gravator.jpg" width="300"/>

## 列表
* 无序列表 
  * 无序列表 1
+ 无序列表
- 无序列表

1. 有序列表 
   1. 有序列表
      1. 有序列表
   2. 有序列表
2. 有序列表
3. 有序列表

## 代码块
`hello` world

```python
def func():
    print('python')
```